@@ -91,16 +91,19 @@ public:
     void setHeaderEncryptionEnabled(bool enabled);
 
     /**
-     * Extract files from archive.
-     * Globally recognized extraction options:
-     * @li PreservePaths - preserve file paths (extract flat if false)
-     * @li RootNode - node in the archive which will correspond to the @arg destinationDirectory
+     * Extracts the given @p files to the given @p destinationDirectory.
+     * If @p files is empty, the whole archive will be extracted.
      * When subclassing, you can block as long as you need (unless you called setWaitForFinishedSignal(true)).
-     * @returns whether the listing succeeded.
+     * @returns whether the extraction succeeded.
      * @note If returning false, make sure to emit the error() signal beforewards to notify
      * the user of the error condition.
      */
     virtual bool extractFiles(const QVector<Archive::Entry*> &files, const QString &destinationDirectory, const ExtractionOptions &options) = 0;
+
+    /**
+     * @return Whether the plugins do NOT run the functions in their own thread.
+     * @see setWaitForFinishedSignal()
+     */
     bool waitForFinishedSignal();
 
     /**
@@ -148,9 +151,11 @@ public:
      */
     static QStringList entryPathsFromDestination(QStringList entries, const Archive::Entry *destination, int entriesWithoutChildren);
 
+    /**
+     * @return true if the interface has killed the job or if it will stop it as soon as possible.
+     * Otherwise returns false if the interface is not able to kill the operation.
+     */
     virtual bool doKill();
-    virtual bool doSuspend();
-    virtual bool doResume();
 
     bool isHeaderEncryptionEnabled() const;
     virtual QString multiVolumeName() const;
@@ -164,6 +169,12 @@ public:
     virtual bool hasBatchExtractionProgress() const;
 
 signals:
+
+    /**
+     * Emitted when the user cancels the operation. Examples:
+     * - the user cancels the password dialog
+     * - the user cancels the overwrite dialog
+     */
     void cancelled();
     void error(const QString &message, const QString &details = QString());
     void entry(Archive::Entry *archiveEntry);
@@ -182,7 +193,7 @@ signals:
 protected:
 
     /**
-     * Setting this option to true will not run the functions in their own thread.
+     * Setting this option to true will NOT run the functions in their own thread.
      * Instead it will be necessary to call finished(bool) when the operation is actually finished.
      */
     void setWaitForFinishedSignal(bool value);
@@ -220,6 +231,15 @@ public:
 
     bool isReadOnly() const override;
 
+    /**
+     * Adds the given @p files under the given @p destination.
+     * If @p destination is null, the files will be added under the root of the archive.
+     * @param options The compression options that must be respected.
+     * @param numberOfEntriesToAdd The total number of entries the will be added.
+     * @return Whether the operation succeeded.
+     * @note If returning false, make sure to emit the error() signal beforewards to notify
+     * the user of the error condition.
+     */
     virtual bool addFiles(const QVector<Archive::Entry*> &files, const Archive::Entry *destination, const CompressionOptions& options, uint numberOfEntriesToAdd = 0) = 0;
     virtual bool moveFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions& options) = 0;
     virtual bool copyFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions& options) = 0;
